@@ -17,6 +17,7 @@ logger = logging.getLogger(__name__)
 class DatabaseService(BaseService):
     def get(self, id_: str) -> Database:
         """Get a Database from Firebolt by its id."""
+
         response = self.client.get(
             url=ACCOUNT_DATABASE_URL.format(account_id=self.account_id, database_id=id_)
         )
@@ -26,11 +27,13 @@ class DatabaseService(BaseService):
 
     def get_by_name(self, name: str) -> Database:
         """Get a Database from Firebolt by its name."""
+
         database_id = self.get_id_by_name(name=name)
         return self.get(id_=database_id)
 
     def get_id_by_name(self, name: str) -> str:
         """Get a Database id from Firebolt by its name."""
+
         response = self.client.get(
             url=ACCOUNT_DATABASE_BY_NAME_URL.format(account_id=self.account_id),
             params={"database_name": name},
@@ -40,10 +43,10 @@ class DatabaseService(BaseService):
 
     def get_many(
         self,
-        name_contains: str,
-        attached_engine_name_eq: str,
-        attached_engine_name_contains: str,
-        order_by: Union[str, DatabaseOrder],
+        name_contains: Optional[str] = None,
+        attached_engine_name_eq: Optional[str] = None,
+        attached_engine_name_contains: Optional[str] = None,
+        order_by: Optional[Union[str, DatabaseOrder]] = None,
     ) -> List[Database]:
         """
         Get a list of databases on Firebolt.
@@ -53,28 +56,42 @@ class DatabaseService(BaseService):
             attached_engine_name_eq: Filter for databases by an exact engine name.
             attached_engine_name_contains: Filter for databases by engines with a
                 name containing this substring.
-            order_by: Method by which to order the results. See [DatabaseOrder].
+            order_by: Method by which to order the results.
+            See :py:class:`firebolt.service.types.DatabaseOrder`.
 
         Returns:
             A list of databases matching the filters.
         """
-        if isinstance(order_by, str):
-            order_by = DatabaseOrder[order_by]
+
+        params = {"page.first": "1000"}
+        if order_by:
+            if isinstance(order_by, str):
+                order_by = DatabaseOrder[order_by]
+            params["order_by"] = order_by.name
+
+        if name_contains:
+            params["filter.name_contains"] = name_contains
+
+        if attached_engine_name_eq:
+            params["filter.attached_engine_name_eq"] = attached_engine_name_eq
+
+        if attached_engine_name_contains:
+            params[
+                "filter.attached_engine_name_contains"
+            ] = attached_engine_name_contains
+
         response = self.client.get(
-            url=ACCOUNT_DATABASES_URL.format(account_id=self.account_id),
-            params={
-                "filter.name_contains": name_contains,
-                "filter.attached_engine_name_eq": attached_engine_name_eq,
-                "filter.attached_engine_name_contains": attached_engine_name_contains,
-                "order_by": order_by.name,
-            },
+            url=ACCOUNT_DATABASES_URL.format(account_id=self.account_id), params=params
         )
+
         return [
-            Database.parse_obj_with_service(obj=d, database_service=self)
-            for d in response.json()["databases"]
+            Database.parse_obj_with_service(obj=d["node"], database_service=self)
+            for d in response.json()["edges"]
         ]
 
-    def create(self, name: str, region: Optional[str] = None) -> Database:
+    def create(
+        self, name: str, region: Optional[str] = None, description: Optional[str] = None
+    ) -> Database:
         """
         Create a new Database on Firebolt.
 
@@ -96,7 +113,9 @@ class DatabaseService(BaseService):
             region_key = self.resource_manager.regions.default_region.key
         else:
             region_key = self.resource_manager.regions.get_by_name(name=region).key
-        database = Database(name=name, compute_region_key=region_key)
+        database = Database(
+            name=name, compute_region_key=region_key, description=description
+        )
 
         logger.info(f"Creating Database (name={name})")
         response = self.client.post(
